# This file was auto-generated by Fern from our API Definition.

import typing

ProjectMetricRequestPublicMetricType = typing.Union[
    typing.Literal[
        "FEEDBACK_SCORES", "TRACE_COUNT", "TOKEN_USAGE", "DURATION", "COST", "GUARDRAILS_FAILED_COUNT", "THREAD_COUNT"
    ],
    typing.Any,
]
